Learn R Programming

squat (version 0.5.0)

autoplot.qts: Plot for qts objects

Description

This function creates a visualization of a QTS and returns the corresponding ggplot2::ggplot object which enable further customization of the plot.

Usage

# S3 method for qts
autoplot(object, highlighted_points = NULL, ...)

Value

A ggplot2::ggplot object.

Arguments

object

An object of class qts.

highlighted_points

An integer vector specifying point indices to be highlighted. Defaults to NULL, in which case no point will be highlighted with respect to the others.

...

Further arguments to be passed on to next methods.

Examples

Run this code
ggplot2::autoplot(vespa64$igp[[1]])

Run the code above in your browser using DataLab