View source: R/qts-transformations.R
| qts2avvts | R Documentation |
This function projects a quaternion time series into the space of angular velocity vectors.
qts2avvts(x, spar = 0)
x |
An object of class qts. |
spar |
smoothing parameter, typically (but not necessarily) in
|
A time series stored as a tibble::tibble with columns time, x,
y and z containing the angular velocity vector at each time point.
qts2avvts(vespa64$igp[[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.