Learn R Programming

squat (version 0.5.0)

qts2rpyts: QTS Transformation to Roll-Pitch-Yaw Time Series

Description

This function converts a quaternion time series into its roll-pitch-yaw angles representation.

Usage

qts2rpyts(x)

Value

A time series stored as a tibble::tibble with columns time, roll, pitch and yaw containing the roll, pitch and yaw angles representation of the input quaternions.

Arguments

x

An object of class qts.

Examples

Run this code
qts2rpyts(vespa64$igp[[1]])

Run the code above in your browser using DataLab