powered by
qts
This function creates a visualization of a QTS and returns the corresponding ggplot2::ggplot object which enable further customization of the plot.
# S3 method for qts autoplot(object, highlighted_points = NULL, ...)
A ggplot2::ggplot object.
An object of class qts.
An integer vector specifying point indices to be highlighted. Defaults to NULL, in which case no point will be highlighted with respect to the others.
NULL
Further arguments to be passed on to next methods.
ggplot2::autoplot(vespa64$igp[[1]])
Run the code above in your browser using DataLab