powered by
qtsclust
This function creates a visualization of the clustering results obtained on a sample of QTS and returns the corresponding ggplot2::ggplot object which enable further customization of the plot.
# S3 method for qtsclust autoplot(object, ...)
A ggplot2::ggplot object.
An object of class qtsclust as produced by kmeans.qts_sample() or hclust.qts_sample().
kmeans.qts_sample()
hclust.qts_sample()
Further arguments to be passed to other methods.
out <- kmeans(vespa64$igp[1:10], n_clusters = 2) ggplot2::autoplot(out)
Run the code above in your browser using DataLab