Learn R Programming

squat (version 0.5.0)

inverse_qts: Inverse Operator for qts Objects

Description

This function implements the pointwise inverse of a quaternion time series.

Usage

inverse_qts(x)

Value

An object of class qts storing the inverse of x.

Arguments

x

An object of class qts.

Examples

Run this code
inverse_qts(vespa64$igp[[1]])

Run the code above in your browser using DataLab