powered by
qts
This function implements the pointwise inverse of a quaternion time series.
inverse_qts(x)
An object of class qts storing the inverse of x.
x
An object of class qts.
inverse_qts(vespa64$igp[[1]])
Run the code above in your browser using DataLab