median.qts_sample: QTS Geometric Median
Description
This function computes the pointwise geometric median of a QTS sample.
Usage
# S3 method for qts_sample
median(x, na.rm = FALSE, ...)
Value
An object of class qts in which quaternions are the
pointwise geometric median of the input QTS sample.
Arguments
- x
An object of class qts_sample.
- na.rm
A logical value indicating whether NA values should be stripped
before the computation proceeds.
- ...
Further arguments passed to or from other methods.