Learn R Programming

squat (version 0.5.0)

qts2aats: QTS Transformation to Angle-Axis Time Series

Description

This function converts a quaternion time series into its angle-axis representation.

Usage

qts2aats(x)

Value

A time series stored as a tibble::tibble with columns time, angle, ux, uy and uz containing the angle-axis representation of the input quaternions.

Arguments

x

An object of class qts.

Examples

Run this code
qts2aats(vespa64$igp[[1]])

Run the code above in your browser using DataLab