powered by
This function converts a quaternion time series into its angle-axis representation.
qts2aats(x)
A time series stored as a tibble::tibble with columns time, angle, ux, uy and uz containing the angle-axis representation of the input quaternions.
time
angle
ux
uy
uz
An object of class qts.
qts2aats(vespa64$igp[[1]])
Run the code above in your browser using DataLab