qts2aavts: QTS Transformation to Angular Acceleration Vector Time Series
Description
This function projects a quaternion time series into the space of angular
acceleration vectors.
Usage
qts2aavts(x, spar = 0)
Value
A time series stored as a tibble::tibble with columns time, x,
y and z containing the angular acceleration vector at each time point.
Arguments
x
An object of class qts.
spar
smoothing parameter, typically (but not necessarily) in
\((0,1]\). When spar is specified, the coefficient
\(\lambda\) of the integral of the squared second derivative in the
fit (penalized log likelihood) criterion is a monotone function of
spar, see the details below. Alternatively lambda may
be specified instead of the scale freespar=\(s\).