View source: R/qts-transformations.R
| qts2avmts | R Documentation |
This function projects a quaternion time series into the space of angular velocity magnitudes.
qts2avmts(x, spar = 0)
x |
An object of class qts. |
spar |
smoothing parameter, typically (but not necessarily) in
|
A time series stored as a tibble::tibble with columns time and
magnitude containing the angular velocity magnitude at each time point.
qts2avmts(vespa64$igp[[1]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.