qts2rpyts: QTS Transformation to Roll-Pitch-Yaw Time Series
Description
This function converts a quaternion time series into its roll-pitch-yaw
angles representation.
Usage
qts2rpyts(x)
Value
A time series stored as a tibble::tibble with columns time,
roll, pitch and yaw containing the roll, pitch and yaw angles
representation of the input quaternions.