Learn R Programming

squat (version 0.5.0)

qts2sqts: QTS Transformation to Smoothed Quaternion Time Series

Description

This function smooths a given QTS using a b-spline functional representation.

Usage

qts2sqts(x, spar = 0)

Value

An object of class qts storing the smoothed QTS.

Arguments

x

An object of class qts.

spar

smoothing parameter, typically (but not necessarily) in \((0,1]\). When spar is specified, the coefficient \(\lambda\) of the integral of the squared second derivative in the fit (penalized log likelihood) criterion is a monotone function of spar, see the details below. Alternatively lambda may be specified instead of the scale free spar=\(s\).

Examples

Run this code
qts2sqts(vespa64$igp[[1]], spar = 0.3)

Run the code above in your browser using DataLab