Learn R Programming

squat (version 0.5.0)

rnorm_qts: QTS Random Sampling

Description

This function adds uncorrelated Gaussian noise to the logarithm QTS using an exponential covariance function.

Usage

rnorm_qts(n, mean_qts, alpha = 0.01, beta = 0.001)

Value

A list of n objects of class qts with added noise as specified by parameters alpha and beta.

Arguments

n

An integer specifying how many QTS should be generated.

mean_qts

An object of class qts specifying the mean QTS.

alpha

A positive scalar specifying the variance of each component of the log-QTS. Defaults to 0.01.

beta

A positive scalar specifying the exponential weight. Defaults to 0.001.

Details

See exp_cov_function for details about the roles of alpha and beta in the definition of the covariance operator.

Examples

Run this code
rnorm_qts(1, vespa64$igp[[1]])

Run the code above in your browser using DataLab