powered by
This function adds uncorrelated Gaussian noise to the logarithm QTS using an exponential covariance function.
rnorm_qts(n, mean_qts, alpha = 0.01, beta = 0.001)
A list of n objects of class qts with added noise as specified by parameters alpha and beta.
n
qts
alpha
beta
An integer specifying how many QTS should be generated.
An object of class qts specifying the mean QTS.
A positive scalar specifying the variance of each component of the log-QTS. Defaults to 0.01.
0.01
A positive scalar specifying the exponential weight. Defaults to 0.001.
0.001
See exp_cov_function for details about the roles of alpha and beta in the definition of the covariance operator.
exp_cov_function
rnorm_qts(1, vespa64$igp[[1]])
Run the code above in your browser using DataLab